Visual Information Fidelity (VIF)
=================================

.. automodule:: viqa.fr_metrics.vif
    :exclude-members: VIFp

   
.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.vif

.. autosummary::
    :toctree: generated/
    :template: class.rst

    VIFp